@@ -11,7 +11,6 @@ Module implementing MainWindow.
 """
 import sys
 
-
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyQt4.QtNetwork import *
@@ -69,6 +68,9 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 		self.isLocalDirectory = {}		
 		self.isRemoteDirectory = {}
 		
+		self.remoteDirs = []
+		self.remoteFiles =[]
+		
 		#Declare openLocation as StackedWindow
 		self.openLocation=OpenServer(self)
 		
@@ -420,7 +422,16 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
             #self.progressDialog.hide()
 			
         elif self.ftp.currentCommand() == QtNetwork.QFtp.List:
-            l1 = 1
+            self.remoteDirs.sort()
+            self.remoteFiles.sort()
+            self.m_lw_remote.clear()
+            self.m_lw_remote.addItem(QListWidgetItem(QIcon("/opt/n900ftp/ressource/folder.xpm"), QString(".."), self.m_lw_remote))
+            for dir in self.remoteDirs:
+                self.m_lw_remote.addItem(QListWidgetItem(QIcon("/opt/n900ftp/ressource/folder.xpm"), dir, self.m_lw_remote))
+            for file in self.remoteFiles:
+                self.m_lw_remote.addItem(file)
+            del self.remoteDirs[:]
+            del self.remoteFiles[:]
 			#if not self.isRemoteDirectory:
                 #self.fileList.addTopLevelItem(QtGui.QTreeWidgetItem(["<empty>"]))
                 #self.fileList.setEnabled(False)
@@ -431,7 +442,6 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 					QtGui.QMessageBox.information(self, "FTP", self.ftp.errorString())
 			   else :
 				   QtGui.QMessageBox.information(self, "FTP", "File successfully deleted!")
-				   self.m_lw_remote.clear()
 				   self.ftp.list()
 
         elif self.ftp.currentCommand() == QtNetwork.QFtp.Rmdir:
@@ -439,7 +449,6 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 					QtGui.QMessageBox.information(self, "FTP", self.ftp.errorString())
 			   else :
 				   QtGui.QMessageBox.information(self, "FTP", "Directory successfully deleted!")
-				   self.m_lw_remote.clear()
 				   self.ftp.list()
 
         elif self.ftp.currentCommand() == QtNetwork.QFtp.Rename:
@@ -447,7 +456,6 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 				QtGui.QMessageBox.information(self,  "FTP",  self.ftp.errorString())
 			else :
 				QtGui.QMessageBox.information(self, "FTP", "File successfully renamed!")
-				self.m_lw_remote.clear()
 				self.ftp.list()
 				
         elif self.ftp.currentCommand() == QtNetwork.QFtp.Mkdir:
@@ -455,18 +463,20 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 				QtGui.QMessageBox.information(self,  "FTP",  self.ftp.errorString())
 			else :
 				QtGui.QMessageBox.information(self, "FTP", "Directory successfully created!")
-				self.m_lw_remote.clear()
 				self.ftp.list()								
 	
 	#QFtp.list() was called, and now the data arrives line by line
     def fillRemoteDirList(self,  ftpItem):
 		#if item is a directory
+		#print "Remote-Directory item: "+ftpItem.name()
 		if ftpItem.isDir():
-			if ftpItem.name() != ".":
+			if ftpItem.name() != "." and ftpItem.name() !="..":
+				self.remoteDirs.append(ftpItem.name())
 				self.isRemoteDirectory[ftpItem.name()]=ftpItem.isDir()
-				self.m_lw_remote.addItem(QListWidgetItem(QIcon("/opt/n900ftp/ressource/folder.xpm"), ftpItem.name(), self.m_lw_remote))
+				#self.m_lw_remote.addItem(QListWidgetItem(QIcon("/opt/n900ftp/ressource/folder.xpm"), ftpItem.name(), self.m_lw_remote))
 		else :
-			self.m_lw_remote.addItem(ftpItem.name())
+			#self.m_lw_remote.addItem(ftpItem.name())
+			self.remoteFiles.append(ftpItem.name())
     
    
     @pyqtSignature("QModelIndex")
@@ -488,7 +498,7 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 		#self.currentRemotePath = self.localdir.path()
 		
 		#add directories to the listwidget first together with an icon
-		filelist = self.localdir.entryList(QDir.AllDirs)
+		filelist = self.localdir.entryList(QDir.AllDirs|QDir.Hidden)
 		for i in filelist:
 			if i == "..":
 				self.m_lw_local.addItem(i)
@@ -497,7 +507,7 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 				self.isLocalDirectory[i]=1
 
 		#now the normal files are added
-		filelist = self.localdir.entryList(QDir.Files)
+		filelist = self.localdir.entryList(QDir.Files|QDir.Hidden)
 		for i in filelist:
 			self.m_lw_local.addItem(i)		
     
@@ -513,9 +523,9 @@ class mMainWindow(QMainWindow, Ui_MainWindow):
 			self.currentRemotePath = self.currentRemotePath.mid(0, lastslash) 
 		else :
 			if self.currentRemotePath=="/":
-				self.currentRemotePath+=newDir
+				self.currentRemotePath+=QString(newDir)
 			else :
-				self.currentRemotePath += "/"+newDir
+				self.currentRemotePath += QString("/"+newDir)
 		#print "Change Remote path to"+self.currentRemotePath		
             
 		self.currentRemoteDir = newDir
